@@ -1,7 +1,8 @@
-from typing import Any, List
-
 import time
 
+from datetime import datetime
+from typing import Any, List
+
 from .__level import __Level as Level
 
 
@@ -10,7 +11,8 @@ class __Message:
     content: str = None
     level: Level = Level.INFO
 
-    def __init__(self, identifier: str, content: Any, level: Level):
+    def __init__(self, timestamp: time.struct_time, identifier: str, content: Any, level: Level):
+        self.timestamp = timestamp
         self.identifier: str = identifier
         self.content: str = self.__convert_to_str(content)
         self.level: Level = level
@@ -30,9 +32,9 @@ class __Message:
 
     def __convert_to_content(self) -> str:
         return "[{}][{}][{}] {}".format(
-            time.strftime("%H:%M:%S", time.localtime()),
+            time.strftime("%d-%m %H:%M:%S", self.timestamp),
             self.identifier,
-            self.level,
+            self.level.value,
             self.content
         )
 
